@@ -56,9 +56,8 @@ rss_html_url_decode(const char *html, int len)
 {
 	xmlDoc *src = NULL;
 	xmlDoc *doc = NULL;
-	gchar *url, *tmpurl;
-	gchar *base_dir = rss_component_peek_base_directory();
-	gchar *feed_dir;
+	gchar *url;
+	gchar *duri = NULL;
 
 	src = (xmlDoc *)parse_html_sux(html, len);
 
@@ -67,29 +66,19 @@ rss_html_url_decode(const char *html, int len)
 
 	doc = src;
 
-	feed_dir = g_build_path(G_DIR_SEPARATOR_S,
-		base_dir,
-		"static",
-		"http",
-		NULL);
-	g_free(base_dir);
-
 	while ((doc = (xmlDoc *)html_find((xmlNode *)doc, (gchar *)"img"))) {
 		if ((url = (gchar *)xmlGetProp((xmlNodePtr)doc, (xmlChar *)"src"))) {
-			if (strstr(url, feed_dir) == NULL) {
-				g_free(feed_dir);
-				return NULL;
+			if (strstr(url, "img:")) {
+				gchar *tmp = decode_image_cache_filename(url);
+				duri = g_strconcat("file://", tmp, NULL);
+				g_free(tmp);
 			}
-			tmpurl = camel_url_decode_path(
-					strstr(url, "http:"));
 			xmlSetProp(
 				(xmlNodePtr)doc,
 				(xmlChar *)"src",
-				(xmlChar *)tmpurl);
-			g_free(tmpurl);
+				(xmlChar *)duri);
 		}
 	}
-	g_free(feed_dir);
 	return src;
 }
 
@@ -364,6 +353,37 @@ html_find (xmlNode *node,
 	return NULL;
 }
 
+/* as html_find() but takes an array of strings for input */
+xmlNode *
+html_find_s (xmlNode *node,
+	gchar **match)
+{
+	guint i;
+	while (node) {
+#ifdef RDF_DEBUG
+		xmlDebugDumpNode (stdout, node, 32);
+		printf("%s.\n", node->name);
+#endif
+		if (node->children)
+			node = node->children;
+		else {
+			while (node && !node->next)
+				node = node->parent;
+			if (!node)
+				return NULL;
+			node = node->next;
+		}
+
+		if (node->name) {
+			for (i = 0; match[i]; i++) {
+				if (!g_strcmp0 ((char *)node->name, match[i]))
+					return node;
+			}
+		}
+	}
+	return NULL;
+}
+
 /* returns node disregarding type
  */
 const char *
@@ -654,6 +674,28 @@ layer_find_pos (xmlNodePtr node,
 	return NULL;
 }
 
+/*
+ * locates a property using a query in the format atribute=property
+ */
+
+gchar *
+layer_query_find_prop (xmlNodePtr node,
+		const char *match,
+		xmlChar *attr,
+		const char *attrprop,
+		xmlChar *prop)
+{
+	node = node->children;
+	while (node!=NULL) {
+		if (!g_ascii_strcasecmp((gchar *)node->name, match)
+		&& (!g_ascii_strcasecmp((gchar *)xmlGetProp(node, attr), attrprop)
+		   || !xmlGetProp(node, attr)))
+					return (gchar *)xmlGetProp(node, prop);
+		node = node->next;
+	}
+	return NULL;
+}
+
 char *
 layer_find_url (xmlNodePtr node,
 		char *match,
@@ -710,7 +752,7 @@ tree_walk (xmlNodePtr root, RDF *r)
 {
 	xmlNodePtr walk;
 	xmlNodePtr rewalk = root;
-	xmlNodePtr channel = NULL, image = NULL, link = NULL;
+	xmlNodePtr channel = NULL, image = NULL;
 	GArray *item = g_array_new (TRUE, TRUE, sizeof (xmlNodePtr));
 	gchar *t;
 	gchar *charset;
@@ -781,6 +823,11 @@ tree_walk (xmlNodePtr root, RDF *r)
 					r->version = g_strdup("1.0");
 				}
 				r->base = (gchar *)xmlGetProp(walk, (xmlChar *)"base");
+				if (!r->base)
+					r->base = layer_query_find_prop (walk,
+							"link",
+							(xmlChar *)"rel",
+							"alternate", (xmlChar *)"href");
 			}
 
 			/* This is the channel top level */
@@ -849,6 +896,8 @@ tree_walk (xmlNodePtr root, RDF *r)
 	return r->title;
 }
 
+static const char *html_const[4] = {"img", "a", NULL};
+
 gchar *
 process_images(gchar *text, gchar *link, gboolean decode, EMFormatHTML *format)
 {
@@ -858,7 +907,7 @@ process_images(gchar *text, gchar *link, gboolean decode, EMFormatHTML *format)
 	xmlDoc *src = (xmlDoc *)parse_html_sux (text, strlen(text));
 	if (src) {
 		xmlNode *doc = (xmlNode *)src;
-		while ((doc = html_find(doc, (gchar *)"img"))) {
+		while ((doc = html_find_s(doc, (gchar **)html_const))) {
 			gchar *name = NULL;
 			xmlChar *url = xmlGetProp(doc, (xmlChar *)"src");
 			if (url) {
@@ -879,6 +928,26 @@ process_images(gchar *text, gchar *link, gboolean decode, EMFormatHTML *format)
 					g_free(name);
 				}
 				xmlFree(url);
+			} else {
+				gchar *url = (gchar *)xmlGetProp(doc, (xmlChar *)"href");
+				if (url
+				&& (g_ascii_strncasecmp (url, "http://", 7) &&
+					g_ascii_strncasecmp (url, "https://", 8) &&
+					g_ascii_strncasecmp (url, "ftp://", 6) &&
+					g_ascii_strncasecmp (url, "nntp://", 7) &&
+					g_ascii_strncasecmp (url, "mailto:", 7) &&
+					g_ascii_strncasecmp (url, "news:", 5) &&
+					g_ascii_strncasecmp (url, "file:", 5) &&
+					g_ascii_strncasecmp (url, "callto:", 7) &&
+					g_ascii_strncasecmp (url, "h323:", 5) &&
+					g_ascii_strncasecmp (url, "sip:", 4) &&
+					g_ascii_strncasecmp (url, "webcal:", 7))) {
+					name = g_build_path(G_DIR_SEPARATOR_S, link, url, NULL);
+					xmlFree(url);
+					xmlSetProp(doc, (xmlChar *)"href",
+						(xmlChar *)name);
+					g_free(name);
+				}
 			}
 		}
 		xmlDocDumpMemory(src, &buff, (int*)&size);
