@@ -84,7 +84,11 @@ update_feed_image(RDF *r)
 	if (!g_file_test(feed_file, G_FILE_TEST_EXISTS)) {
 	if (image) {		//we need to validate image here with load_pixbuf
 		CamelStream *feed_fs = camel_stream_fs_new_with_name(feed_file,
+#if EVOLUTION_VERSION < 23191
 			O_RDWR|O_CREAT, 0666);
+#else
+			O_RDWR|O_CREAT, 0666, NULL);
+#endif
 		dup_auth_data(r->uri, image);
 		fi->feed_fs = feed_fs;
 		fi->key = g_strdup(key);
@@ -279,7 +283,11 @@ finish_image_feedback (SoupSession *soup_sess, SoupMessage *msg, FEED_IMAGE *use
 	stream = rss_cache_add(user_data->url);
 	finish_image(soup_sess, msg, stream);
 	if (user_data->data == current_pobject)
+#if EVOLUTION_VERSION >= 23190
+		em_format_queue_redraw((EMFormat *)user_data->data);
+#else
 		em_format_redraw((EMFormat *)user_data->data);
+#endif
 	g_free(user_data->url);
 	g_free(user_data);
 }
@@ -313,9 +321,15 @@ finish_image (SoupSession *soup_sess, SoupMessage *msg, CamelStream *user_data)
 		if (msg->response_body->data) {
 			camel_stream_write(user_data,
 				msg->response_body->data,
+#if EVOLUTION_VERSION < 23191
 				msg->response_body->length);
-#endif
 			camel_stream_close(user_data);
+#else
+				msg->response_body->length,
+				NULL);
+			camel_stream_close(user_data, NULL);
+#endif
+#endif
 #if (DATASERVER_VERSION >= 2031001)
 			g_object_unref(user_data);
 #else
@@ -323,8 +337,13 @@ finish_image (SoupSession *soup_sess, SoupMessage *msg, CamelStream *user_data)
 #endif
 		}
 	} else {
+#if EVOLUTION_VERSION < 23191
 		camel_stream_write(user_data, pixfilebuf, pixfilelen);
 		camel_stream_close(user_data);
+#else
+		camel_stream_write(user_data, pixfilebuf, pixfilelen, NULL);
+		camel_stream_close(user_data, NULL);
+#endif
 #if (DATASERVER_VERSION >= 2031001)
 		g_object_unref(user_data);
 #else
@@ -340,10 +359,16 @@ finish_create_icon (SoupMessage *msg, FEED_IMAGE *user_data)
 finish_create_icon (SoupSession *soup_sess, SoupMessage *msg, FEED_IMAGE *user_data)
 #endif
 {
-	d("finish_image(): status:%d, user_data:%s\n", msg->status_code, user_data->img_file);
+	d("finish_image(): status:%d, user_data:%s\n",
+		msg->status_code, user_data->img_file);
 	if (404 != msg->status_code) {
-		CamelStream *feed_fs = camel_stream_fs_new_with_name(user_data->img_file,
-			O_RDWR|O_CREAT, 0666);
+		CamelStream *feed_fs = camel_stream_fs_new_with_name(
+					user_data->img_file,
+#if EVOLUTION_VERSION < 23191
+					O_RDWR|O_CREAT, 0666);
+#else
+					O_RDWR|O_CREAT, 0666, NULL);
+#endif
 		finish_image(soup_sess, msg, feed_fs);
 #if (EVOLUTION_VERSION >= 22703)
 		display_folder_icon(evolution_store, user_data->key);
@@ -384,7 +409,7 @@ display_folder_icon(GtkTreeStore *tree_store, gchar *key)
 	EMFolderTreeModel *mod = (EMFolderTreeModel *)tree_store;
 	struct _EMFolderTreeModelStoreInfo *si;
 	CamelStore *store = rss_component_peek_local_store();
-	CamelFolder *rss_folder;
+	CamelFolderInfo *rssi;
 	gint i=0, size;
 	gint *sizes;
 
@@ -394,14 +419,15 @@ display_folder_icon(GtkTreeStore *tree_store, gchar *key)
 
 	if (pixbuf) {
 		gchar *name = g_hash_table_lookup(rf->hrname_r, key);
-		gchar *full_name = g_strdup_printf(
-					"%s" G_DIR_SEPARATOR_S "%s",
+		gchar *full_name = g_build_path(
+					G_DIR_SEPARATOR_S,
 					get_main_folder(),
-					lookup_feed_folder(name));
-		rss_folder = camel_store_get_folder (
+					lookup_feed_folder(name),
+					NULL);
+		rssi = camel_store_get_folder_info (
 					store,
 					full_name, 0, NULL);
-		if (!rss_folder) {
+		if (!rssi) {
 			g_free(full_name);
 			result = FALSE;
 			goto out;
@@ -438,11 +464,7 @@ display_folder_icon(GtkTreeStore *tree_store, gchar *key)
 				COL_STRING_ICON_NAME, key,
 				-1);
 		g_free(full_name);
-#if (DATASERVER_VERSION >= 2031001)
-		g_object_unref (rss_folder);
-#else
-		camel_object_unref (rss_folder);
-#endif
+		camel_store_free_folder_info (store, rssi);
 		g_object_unref(pixbuf);
 		result = TRUE;
 	}
@@ -469,6 +491,9 @@ decode_image_cache_filename(gchar *name)
 
 gboolean image_is_valid(gchar *image);
 
+gboolean
+file_is_image(gchar *image);
+
 gboolean
 file_is_image(gchar *image)
 {
